@@ -324,6 +324,7 @@ public:
 						// minus the value for 'refine, potential N-terminus modification position limit' before performing cleavage
 	vector<int> m_viQuality; // contains the data quality scoring vector
 	map<uint64_t,size_t> m_mapCrc;
+	size_t m_tTemp;
 	bool m_bReversedOnly;
 	bool m_bSaps;
 	bool m_bAnnotation;
@@ -337,6 +338,8 @@ public:
 	double m_dNtAve;
 	double m_dNg;
 	double m_dNgAve;
+	float m_fMaxMass;
+	float m_fMaxZ;
 	enum	{
 		I_Y =	0x01,
 		I_B =	0x02,
