@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2003-2011 Ronald C Beavis, all rights reserved
+ Copyright (C) 2003-2013 Ronald C Beavis, all rights reserved
  X! tandem 
  This software is a component of the X! proteomics software
  development project
@@ -128,7 +128,7 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 The End 
 */
 
-// File version: 2011-12-01
+// File version: 2013-04-01
 
 /*
 	tandem.cpp provides a command line interface to the main processing class, mprocess.
@@ -184,7 +184,7 @@ int main(int argc, char* argv[])
 	if(argc < 2 || argc > 1 && strstr(argv[1],"-L") == argv[1] || argc > 1 && strstr(argv[1],"-h") == argv[1])	{
 		cout << "\n\nUSAGE: tandem filename\n\nwhere filename is any valid path to an XML input file.\n\n+-+-+-+-+-+-+\n";
  		cout << "\nX! TANDEM " << VERSION << "\n";
-		cout << "\nCopyright (C) 2003-2011 Ronald C Beavis, all rights reserved\n";
+		cout << "\nCopyright (C) 2003-2013 Ronald C Beavis, all rights reserved\n";
  		cout << "This software is a component of the GPM  project.\n";
 		cout << "Use of this software governed by the Artistic license.\n";
 		cout << "If you do not have this license, you can get a copy at\n";
@@ -199,7 +199,7 @@ int main(int argc, char* argv[])
 	/*
 	* Create an mprocess object array
 	*/
-	unsigned long lMaxThreads = 16;
+	unsigned long lMaxThreads = 256;
 	mprocess **pProcess = new mprocess*[lMaxThreads];
 	if(pProcess == NULL)	{
 		cout << "An error was detected creating the processing objects.\nPlease contact a GPM administrator.\n";
@@ -275,6 +275,12 @@ int main(int argc, char* argv[])
 	bool bSpectra =	true;
 	cout <<	"Starting threads .";
 	cout.flush();
+	size_t tCount = pProcess[0]->m_vSpectra.size();
+	sort(pProcess[0]->m_vSpectra.begin(),pProcess[0]->m_vSpectra.end(),lessThanSpec);
+	float fMax = (float)pProcess[0]->m_vSpectra.back().m_dMH;
+	float fZ = pProcess[0]->m_vSpectra.back().m_fZ;
+	pProcess[0]->m_fMaxMass = fMax;
+	pProcess[0]->m_fMaxZ = fZ;
 	if(lThread != 0xFFFFFFFF)		{
 		while(dCount > 0)		{
 			pProcess[dCount] = new mprocess;
@@ -285,10 +291,10 @@ int main(int argc, char* argv[])
 
 			*/
 			pProcess[dCount]->m_vSpectra.reserve(lSpectra);
+			pProcess[dCount]->m_fMaxMass = fMax;
+			pProcess[dCount]->m_fMaxZ = fZ;
 			dCount--;
 		}
-		size_t tCount = pProcess[0]->m_vSpectra.size();
-		sort(pProcess[0]->m_vSpectra.begin(),pProcess[0]->m_vSpectra.end(),lessThanSpec);
 
 		size_t tProcesses = lThreads;
 		size_t tRing = 0;
